==> redquicklib-1.6.0.tgz: package/lib/screens/signout.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
    Container,
    Header,
    Content,
    Card,
    CardItem,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    CheckBox,
    InputGroup, Title,
    Body, Left, Right,
    Text, Picker,
    Input,
} from 'native-base';
import QuickContainer from '../../components/herocontainer';
import * as Common from '../customer/common';
import ReactSignOut from '../../components/reactnativesignout';
import {
    StyleSheet,
    AsyncStorage,
    View,
    Dimensions, Alert
} from 'react-native';
import * as UIA from '../../actions/uiActions';
import * as ILA from '../../actions/identityLoginActions';
import * as utils from '../../util/util';
import { Colors } from '../../colors';
import * as Keys from '../keys';
import * as Titles from '../../titles';
import { Actions } from 'react-native-router-flux';
import * as Globals from '../../util/globals';
const Item = Picker.Item;
class SignOut extends Component {
    constructor(props) {
        super(props);
        this.state = {
            checked: {}
        };
    }

    render() {
        var me = this;
        var { state } = me.props;
        var identityProvider = UIA.Get(state, ILA.IDENTITY_PROVIDER);;
        var address = `https://herocarcare-v1.azurewebsites.net/Account/LogOff`;
        var googleSignOut = Globals.DEFAULT_URL + `Logout`;
        var SignOutComplete = Globals.DEFAULT_URL + `Complete`;

        var heroSignOut = Globals.DEFAULT_URL + `Account/LogOff`;
        var heroSignOutComplete = Globals.DEFAULT_URL_ + ``;
        return (
            <ReactSignOut
                signoutUrl={heroSignOut}
                signoutUrlComplete={SignOutComplete}
                signoutHeroUrl={heroSignOut}
                signoutHeroUrlComplete={heroSignOutComplete}
                onSignOutComplete={(e) => {
                    UIA.log('navigated to logged in state');
                    UIA.log(e);
                    me.props.resetAll(() => {
                        me.props.logout(Actions.login);
                    });
                }}>
            </ReactSignOut>
        );
    }
}


const styles = StyleSheet.create({
    picker: {
        width: 100,
    },
    container: Object.assign({}, StyleSheet.absoluteFillObject, {
        justifyContent: 'flex-end',
        height: 400,
        top: 40,
        width: 400,
        alignItems: 'center',
    }),
    map: Object.assign({}, StyleSheet.absoluteFillObject)
});


export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(SignOut);

==> redquicklib-1.289.0.tgz: package/lib/screens/signout.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
    Container,
    Header,
    Content,
    Card,
    CardItem,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    CheckBox,
    InputGroup, Title,
    Body, Left, Right,
    Text, Picker,
    Input,
} from 'native-base';
import * as Common from '../common';
import ReactSignOut from '../components/reactnativesignout';
import {
    StyleSheet,
    AsyncStorage,
    View,
    Dimensions, Alert
} from 'react-native';
import * as UIA from '../actions/uiActions';
import * as utils from '../util';
import { Colors } from '../colors';
import * as Keys from '../keys';
import * as Titles from '../titles';
import { Actions } from 'react-native-router-flux';
import * as Globals from '../globals';
const Item = Picker.Item;
class SignOut extends Component {
    constructor(props) {
        super(props);
        this.state = {
            checked: {}
        };
    }

    render() {
        var me = this;
        var { state } = me.props;
        var identityProvider = UIA.Get(state, UIA.IDENTITY_PROVIDER);;
        var address = `https://herocarcare-v1.azurewebsites.net/Account/LogOff`;
        var googleSignOut = Globals.DEFAULT_URL + `Logout`;
        var SignOutComplete = Globals.DEFAULT_URL + `Complete`;

        var heroSignOut = Globals.DEFAULT_URL + `Account/LogOff`;
        var heroSignOutComplete = Globals.DEFAULT_URL_ + ``;
        return (
            <ReactSignOut
                signoutUrl={heroSignOut}
                signoutUrlComplete={SignOutComplete}
                signoutHeroUrl={heroSignOut}
                signoutHeroUrlComplete={heroSignOutComplete}
                onSignOutComplete={(e) => {
                    UIA.log('navigated to logged in state');
                    UIA.log(e);
                    me.props.resetAll(() => {
                        me.props.logout(Actions.login);
                    });
                }}>
            </ReactSignOut>
        );
    }
}


const styles = StyleSheet.create({
    picker: {
        width: 100,
    },
    container: Object.assign({}, StyleSheet.absoluteFillObject, {
        justifyContent: 'flex-end',
        height: 400,
        top: 40,
        width: 400,
        alignItems: 'center',
    }),
    map: Object.assign({}, StyleSheet.absoluteFillObject)
});


export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(SignOut);
